@@ -6,30 +6,42 @@ from .keys import app_id, app_code
 
 
 class Nokia(Base):
-    provider = 'Nokia'
-    api = 'HERE Geocoding REST API'
-    url = 'http://geocoder.api.here.com/6.2/geocode.json'
-    _description = 'Send a request to the geocode endpoint to find an address using a combination of\n'
-    _description += 'country, state, county, city, postal code, district, street and house number.'
-    _api_reference = ['[{0}](https://developer.here.com/rest-apis/documentation/geocoder)'.format(api)]
-    _api_parameter  = [':param app_id: (optional) use your own Application ID from Nokia.']
-    _api_parameter  = [':param app_code: (optional) use your own Application Code from Nokia.']
+    """
+    HERE Geocoding REST API
+    =======================
+    Send a request to the geocode endpoint to find an address 
+    using a combination of country, state, county, city, 
+    postal code, district, street and house number.
 
-    def __init__(self, location, app_id=app_id, app_code=app_code):
+    API Reference
+    -------------
+    https://developer.here.com/rest-apis/documentation/geocoder
+
+    OSM Quality (6/6)
+    -----------------
+    [x] addr:housenumber
+    [x] addr:street
+    [x] addr:city
+    [x] addr:state
+    [x] addr:country
+    [x] addr:postal
+    """
+    provider = 'nokia'
+    method = 'geocode'
+
+    def __init__(self, location, **kwargs):
+        self.url = 'http://geocoder.api.here.com/6.2/geocode.json'
         self.location = location
         self.json = dict()
         self.parse = dict()
-        self.params = dict()
-        self.params['searchtext'] = location
-        self.params['app_id'] = app_id
-        self.params['app_code'] = app_code
-        self.params['gen'] = 4
-
-        # Initialize
-        self._connect()
-        self._parse(self.content)
-        self._test()
-        self._json()
+        self.content = None
+        self.params = {
+            'searchtext': location,
+            'app_id': kwargs.get('app_id', app_id),
+            'app_code': kwargs.get('app_code', app_code),
+            'gen': 4,
+        }
+        self._initialize(**kwargs)
 
     @property
     def lat(self):
@@ -44,13 +56,42 @@ class Nokia(Base):
         return self._get_json_str('Address-Label')
 
     @property
-    def street_number(self):
+    def postal(self):
+        return self._get_json_str('Address-PostalCode')
+
+    @property
+    def housenumber(self):
         return self._get_json_str('Address-HouseNumber')
 
     @property
-    def route(self):
+    def street(self):
         return self._get_json_str('Address-Street')
 
+    @property
+    def neighborhood(self):
+        return self._get_json_str('Address-District')
+
+    @property
+    def city(self):
+        return self._get_json_str('Address-City')
+
+    @property
+    def county(self):
+        return self._get_json_str('Address-County')
+
+    @property
+    def state(self):
+        state_1 = self._get_json_str('Address-StateName')
+        state_2 = self._get_json_str('StateName')
+        if state_1:
+            return state_1
+        elif state_2:
+            return state_2 
+
+    @property
+    def country(self):
+        return self._get_json_str('CountryName')
+
     @property
     def quality(self):
         return self._get_json_str('Result-MatchLevel')
@@ -59,10 +100,6 @@ class Nokia(Base):
     def accuracy(self):
         return self._get_json_str('Result-MatchType')
 
-    @property
-    def postal(self):
-        return self._get_json_str('Address-PostalCode')
-
     @property
     def bbox(self):
         south = self._get_json_float('BottomRight-Latitude')
@@ -71,27 +108,6 @@ class Nokia(Base):
         east = self._get_json_float('BottomRight-Longitude')
         return self._get_bbox(south, west, north, east)
 
-    @property
-    def neighborhood(self):
-        return self._get_json_str('Address-District')
-
-    @property
-    def locality(self):
-        return self._get_json_str('Address-City')
-
-    @property
-    def county(self):
-        return self._get_json_str('Address-County')
-
-    @property
-    def state(self):
-        return self._get_json_str('Address-StateName')
-
-    @property
-    def country(self):
-        return self._get_json_str('CountryName')
-
 if __name__ == '__main__':
-    g = Nokia('Kingston Ontario')
-    g.help()
+    g = Nokia('1552 Payette dr., Ottawa ON')
     g.debug()
\ No newline at end of file
